# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

[Open a ticket](https://gitlab.com/askanna/askanna-python/issues) or create a merge request, and start adding features
to AskAnna!
